# capedu

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)
[![PyPI version](https://badge.fury.io/py/capedu.svg)](https://badge.fury.io/py/capedu)
[![Build Status](https://travis-ci.org/msalaztor/capedu.svg?branch=master)](https://travis-ci.org/msalaztor/capedu)
[![Documentation Status](https://readthedocs.org/projects/capedu/badge/?version=latest)](https://capedu.readthedocs.io/en/latest/?badge=latest)

Libreria para calcular el Coeficiente de Adecuación Patrimonial.

## Funcionalidades

- Calculo del Coeficiente de Adecuación Patrimonial.

## Installation

```bash
pip install capedu

import capedu

